[Pkg-owncloud-commits] [owncloud] 47/104: Now also preventing to override "files" dir size with -1

David Prévot taffit at moszumanska.debian.org
Sat Jan 18 13:33:39 UTC 2014


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch master
in repository owncloud.

commit 542cf79595c9905e93aeb927daab938b4fe15d1e
Author: Vincent Petry <pvince81 at owncloud.com>
Date:   Tue Jan 7 17:41:04 2014 +0100

    Now also preventing to override "files" dir size with -1
    
    Fixes #6526
    
    Backport of 5be4af9 to stable6
---
 lib/private/files/cache/homecache.php |  2 +-
 tests/lib/files/cache/homecache.php   | 18 ++++++++++++------
 2 files changed, 13 insertions(+), 7 deletions(-)

diff --git a/lib/private/files/cache/homecache.php b/lib/private/files/cache/homecache.php
index 18dfbfe..71bb944 100644
--- a/lib/private/files/cache/homecache.php
+++ b/lib/private/files/cache/homecache.php
@@ -16,7 +16,7 @@ class HomeCache extends Cache {
 	 * @return int
 	 */
 	public function calculateFolderSize($path) {
-		if ($path !== '/' and $path !== '') {
+		if ($path !== '/' and $path !== '' and $path !== 'files') {
 			return parent::calculateFolderSize($path);
 		}
 
diff --git a/tests/lib/files/cache/homecache.php b/tests/lib/files/cache/homecache.php
index 2fa7f1b..87fd0db 100644
--- a/tests/lib/files/cache/homecache.php
+++ b/tests/lib/files/cache/homecache.php
@@ -62,33 +62,39 @@ class HomeCache extends \PHPUnit_Framework_TestCase {
 	}
 
 	/**
 	 * Tests that the root folder size calculation ignores the subdirs that have an unknown
 	 * size. This makes sure that quota calculation still works as it's based on the root
 	 * folder size.
 	 */
 	public function testRootFolderSizeIgnoresUnknownUpdate() {
-		$dir1 = 'knownsize';
-		$dir2 = 'unknownsize';
+		$dir1 = 'files/knownsize';
+		$dir2 = 'files/unknownsize';
 		$fileData = array();
 		$fileData[''] = array('size' => -1, 'mtime' => 20, 'mimetype' => 'httpd/unix-directory');
+		$fileData['files'] = array('size' => -1, 'mtime' => 20, 'mimetype' => 'httpd/unix-directory');
 		$fileData[$dir1] = array('size' => 1000, 'mtime' => 20, 'mimetype' => 'httpd/unix-directory');
 		$fileData[$dir2] = array('size' => -1, 'mtime' => 25, 'mimetype' => 'httpd/unix-directory');
 
 		$this->cache->put('', $fileData['']);
+		$this->cache->put('files', $fileData['files']);
 		$this->cache->put($dir1, $fileData[$dir1]);
 		$this->cache->put($dir2, $fileData[$dir2]);
 
+		$this->assertTrue($this->cache->inCache('files'));
 		$this->assertTrue($this->cache->inCache($dir1));
 		$this->assertTrue($this->cache->inCache($dir2));
 
-		// check that root size ignored the unknown sizes
+		// check that files and root size ignored the unknown sizes
+		$this->assertEquals(1000, $this->cache->calculateFolderSize('files'));
 		$this->assertEquals(1000, $this->cache->calculateFolderSize(''));
 
 		// clean up
 		$this->cache->remove('');
+		$this->cache->remove('files');
 		$this->cache->remove($dir1);
 		$this->cache->remove($dir2);
 
+		$this->assertFalse($this->cache->inCache('files'));
 		$this->assertFalse($this->cache->inCache($dir1));
 		$this->assertFalse($this->cache->inCache($dir2));
 	}
@@ -62,33 +62,39 @@ class HomeCache extends \PHPUnit_Framework_TestCase {
 
 	/**
-	 * Tests that the root folder size calculation ignores the subdirs that have an unknown
-	 * size. This makes sure that quota calculation still works as it's based on the root
-	 * folder size.
+	 * Tests that the root and files folder size calculation ignores the subdirs
+	 * that have an unknown size. This makes sure that quota calculation still
+	 * works as it's based on the "files" folder size.
 	 */
 	public function testRootFolderSizeIgnoresUnknownUpdate() {

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud.git



More information about the Pkg-owncloud-commits mailing list